@@ -36,7 +36,7 @@ class Command(BaseCommand):
         os.mkdir(databases_dir)
         logging.info(f"Created Databases Directory {databases_dir}")
         for database in Database.objects.all():
-            logging.info("Exporting Database {database}")
+            logging.info(f"Exporting Database {database}")
             db_dir = os.path.join(pwd, "databases", database.handle)
             os.mkdir(db_dir)
             db_meta = {
@@ -53,7 +53,7 @@ class Command(BaseCommand):
         os.mkdir(source_tables_dir)
         logging.info(f"Created SourceTables Directory {source_tables_dir}")
         for source in SourceTable.objects.all():
-            logging.info("Exporting SourceTabe {source}")
+            logging.info(f"Exporting SourceTabe {source}")
             source_dir = os.path.join(pwd, "source_tables", str(source.pk))
             os.mkdir(source_dir)
             source_meta = {
@@ -67,7 +67,7 @@ class Command(BaseCommand):
         os.mkdir(reflections_dir)
         logging.info(f"Created Reflections Directory {reflections_dir}")
         for reflection in Reflection.objects.all():
-            logging.info("Exporting Reflection {reflection}")
+            logging.info(f"Exporting Reflection {reflection}")
             reflection_dir = os.path.join(
                 pwd,
                 "reflections",
@@ -106,4 +106,4 @@ class Command(BaseCommand):
                         reflection_dir,
                         "reflection_statment.sql"
                     ), "w") as file:
-                file.write(json.dumps(reflection_statment, indent=4))
+                file.write(reflection_statment)
